===============================
Goldilocks
===============================

.. image:: https://badge.fury.io/py/goldilocks.png
    :target: http://badge.fury.io/py/goldilocks

.. image:: https://travis-ci.org/SamStudio8/goldilocks.png?branch=master
        :target: https://travis-ci.org/SamStudio8/goldilocks

.. image:: https://coveralls.io/repos/SamStudio8/goldilocks/badge.png?branch=master
        :target: https://coveralls.io/r/SamStudio8/goldilocks

Locating genomic regions that are "just right".

* Documentation: http://goldilocks.readthedocs.org.

Requirements
------------
To use;

* numpy

To test;

* tox
* pytest

For coverage;

* nose
* python-coveralls

Installation
------------

::

    $ pip install goldilocks

